const path = require('path');

module.exports = {
  cacheDirectory: '.jest-cache',
  moduleFileExtensions: ['ts', 'tsx', 'js', 'jsx', 'json', 'node'],
  transform: {
    '^.+\\.tsx?$': require.resolve('ts-jest'),
  },

  moduleNameMapper: {
    '\\.(jpg|jpeg|png|gif|eot|otf|webp|svg|ttf|woff|woff2|mp4|webm|wav|mp3|m4a|aac|oga)$':
      'identity-obj-proxy',
    '\\.(css|less|scss|sass)$': 'identity-obj-proxy',
  },

  // Use custom resolver that will try to find the `src:ts` field
  // in a package.json file first. This way, we can ensure
  // our source files will be used regardless of the `dist`
  // folder
  resolver: path.join(__dirname, 'resolver.js'),

  reporters: ['default', 'jest-junit'],

  testEnvironment: 'jsdom',
  setupFilesAfterEnv: [path.resolve(__dirname, './jest.setup.ts')],

  coverageDirectory: '<rootDir>/.jest-coverage',
  coveragePathIgnorePatterns: ['<rootDir>/packages/(?:.+?)/dist/'],
  coverageReporters: ['html', 'text'],
  coverageThreshold: {
    global: {
      branches: 80,
      functions: 80,
      lines: 80,
      statements: 80,
    },
  },
  testPathIgnorePatterns: ['<rootDir>/packages/(?:.+?)/dist/'],
};
